// Test case for:
// - https://jira.appcelerator.org/browse/TC-1557 
//   incorrect blob encoding prevents image from showing on Mobile Web)
// - https://jira.appcelerator.org/browse/TC-1792
//   (properties "file" and "nativePath" do not work on Mobile Web)
//
// The bugs is fixed by pull request: https://github.com/appcelerator/titanium_mobile/pull/3693
//
// Current behavior before the proposed pull request:
// - MobileWeb: no images are shown
// - Other platforms: one image is shown (appcelerator logo)
// Behavior after the proposed pull request:
// - MobileWeb: two identical images are shown (appcelerator logo)
// - Other platforms: no change


(function() {
	
	var win = Titanium.UI.createWindow({backgroundColor:"black"});
	
	var downloadButton = Titanium.UI.createButton({
	    title:'Download image',
	    top:2,
	    width:200,
	    height:40
	});
	win.add(downloadButton);
	
	var imageView1 = Titanium.UI.createImageView({
		top:50,
		left:10,
		height:100,
		width:80
	});
	win.add(imageView1);
	
	var imageView2 = Titanium.UI.createImageView({
		top:160,
		left:10,
		height:100,
		width:80
	});
	win.add(imageView2);
	
	var isMobileWeb = Ti.Platform.osname == "mobileweb",
		xhr = Titanium.Network.createHTTPClient();
	
	xhr.onload = function()
	{
		Ti.API.info("Onload");
		
		var blob = xhr.responseData;
		
		Ti.API.info('Blob with Base64-encoded data:'+blob);
		
		// TC-1557:
		// Image will NOT appear on MobileWeb due to TC-1557 (incorrect behavior).
		// (Image will appear on iOS and Android.)
		imageView1.image = blob;
		
		// TC-1792:
		// Properties 'file' and 'nativePath' aren`t set in Mobile Web
		if (!!blob.file) {
		
			Ti.API.info('File name:'+blob.nativePath);
			
			//load data from file to ImageView2
			imageView2.image = blob.file.read();	
		} else {
			// In non-Mobile Web, TC-1792 does not apply.
			Ti.API.info("Property 'file' is missing");
		}
	};
	
	downloadButton.addEventListener('click',function() {
		
		// Some Mobile Web browsers prevent getting images from other domains due to security concerns.
		// This is why we load the image from different locations, depending on the browser.
		// The bug demonstration does not depend on this difference.
		if (isMobileWeb) {
			// Get a local file to demonstrate TC-1557
			xhr.open('GET','/images/a-logo.png');
			
			// Initialize 'file' to demonstrate TC-1792
			xhr.file = Ti.Filesystem.applicationDataDirectory + 'a-logo.png';
		} else {
			// Get a file from the Internet to demonstrate TC-1557
			xhr.open('GET','http://developer.appcelerator.com/blog/wp-content/themes/newapp/images/appcelerator_avatar.png');
			
			// In non-Mobile Web, TC-1792 does not apply.
		}
		
		xhr.send();
	});
	
	win.open();
	
})();